package com.tenlionsoft.aimz_k.page.activity

import android.app.Activity
import android.util.Log
import android.view.WindowManager
import androidx.activity.result.contract.ActivityResultContracts
import androidx.core.content.ContextCompat
import androidx.databinding.DataBindingUtil
import androidx.lifecycle.ViewModelProvider
import com.atwa.filepicker.core.FilePicker
import com.tenlionsoft.aimz_k.R
import com.tenlionsoft.aimz_k.databinding.ActivityChatBinding
import com.tenlionsoft.aimz_k.model.PickerType
import com.tenlionsoft.aimz_k.viewmodel.ChatPageViewModel
import com.tenlionsoft.baselib.base.BaseActivity
import com.tenlionsoft.baselib.widget.wheel.WheelView

/**
 * 聊天页面
 */
class ChatActivity : BaseActivity() {
    private lateinit var mBinding: ActivityChatBinding
    private val chatPageViewModel: ChatPageViewModel by lazy {
        ViewModelProvider(this)[ChatPageViewModel::class.java]
    }
    private val launcher =
        registerForActivityResult(ActivityResultContracts.StartActivityForResult()) {
            if (it.resultCode == Activity.RESULT_OK) {
                // Use the uri to load the image
//                val uri = it.data?.data!!
                // Use the file path to set image or upload
//                val filePath= it.data?.getStringExtra(Const.BundleExtras.FILE_PATH)
                //...

                // for Multiple picks
                // first item
//                val first = it.data?.data!!
                // other items
//                val  clipData = it.data?.clipData
                // Multiple file paths list
//                val filePaths = result.data?.getStringArrayListExtra(Const.BundleExtras.FILE_PATH_LIST)
                //...
            }
        }
    private val filePicker = FilePicker.getInstance(this)
    override fun bindView() {
        mBinding = DataBindingUtil.setContentView(this, R.layout.activity_chat);
        window.addFlags(WindowManager.LayoutParams.FLAG_DRAWS_SYSTEM_BAR_BACKGROUNDS)
        window.statusBarColor =
            ContextCompat.getColor(this, com.tenlionsoft.baselib.R.color.chat_page_bg)
        mBinding.ivBack.setOnClickListener { finish(); }
        mBinding.srlChats.setEnableRefresh(false)
        mBinding.srlChats.setEnableLoadMore(false)
        mBinding.viewModel = chatPageViewModel
        mBinding.lifecycleOwner = this
        //选择emoji
        mBinding.rpvEmoji.setOnEmojiPickedListener {
            mBinding.etMsg.append(it.emoji)
        }
        //显示/隐藏软键盘
        chatPageViewModel.showSoftKeyboard.observe(this) {
            if (it) {
                showSoftKeyBoard(mBinding.etMsg)
                chatPageViewModel.showChooseLayout.value = false
                chatPageViewModel.showEmojiLayout.value = false
                chatPageViewModel.showReplyLayout.value = false
            } else {
                hideSoftKeyboard()
            }
        }
        mBinding.rlContent.setOnClickListener {
            chatPageViewModel.showChooseLayout.value = false
            chatPageViewModel.showEmojiLayout.value = false
            chatPageViewModel.showReplyLayout.value = false
            hideSoftKeyboard()
        }
        mBinding.wvView.setTextSize(14F, isSp = true)
        mBinding.wvView.setAutoFitTextSize(true)
        mBinding.wvView.setOnItemSelectedListener(object : WheelView.OnItemSelectedListener {
            override fun onItemSelected(wheelView: WheelView, data: Any, position: Int) {
                mBinding.etMsg.setText(data.toString())
            }
        })
        chatPageViewModel.chooseType.observe(this) {
            when (it) {
                PickerType.TYPE_PIC -> {
                    filePicker
                        .pickMultiImage { list ->
                            if (list.isNotEmpty()) {
                                chatPageViewModel.uploadImages(list)
                            }
                        }
                }

                PickerType.TYPE_VIDEO -> {
                    filePicker.pickVideo { mate ->
                        if (mate != null) {
                            chatPageViewModel.uploadVideo(mate)
                        }
                    }
                }

                PickerType.TYPE_FILE -> {
                    filePicker.pickFile { meta ->
                        if (meta != null) {
                            chatPageViewModel.uploadFiles(meta)
                        }
                    }
                }

                else -> {}
            }
        }

//        chatPageViewModel.showReplyLayout.observe(this) {
//            if (it) {
//                hideSoftKeyboard()
//            }
//        }
//        chatPageViewModel.showEmojiLayout.observe(this) {
//            if (it) {
//                hideSoftKeyboard()
//            }
//        }
//        chatPageViewModel.showChooseLayout.observe(this) {
//            if (it) {
//                hideSoftKeyboard()
//            }
//        }

//        rootView = findViewById(android.R.id.content)
//        rootView.viewTreeObserver.addOnGlobalLayoutListener {
//            val r = Rect()
//            rootView.getWindowVisibleDisplayFrame(r)
//            val screenHeight = rootView.rootView.height
//            val heightDiff = screenHeight - (r.bottom - r.top)
//            Log.e("ChatActivity", "bindView: ${heightDiff}")
//            if (heightDiff > 100) {
//                chatPageViewModel.showEmojiLayout.value = false
//                chatPageViewModel.showReplyLayout.value = false
//                chatPageViewModel.showChooseLayout.value = false
//            }
//        }
    }

}


//XXPermissions.with(this)
//// 申请单个权限
//.permission(Permission.RECORD_AUDIO)
//// 申请多个权限
//.permission(Permission.Group.CALENDAR)
//// 设置权限请求拦截器（局部设置）
////.interceptor(new PermissionInterceptor())
//// 设置不触发错误检测机制（局部设置）
////.unchecked()
//.request(object : OnPermissionCallback {
//
//    override fun onGranted(permissions: MutableList<String>, allGranted: Boolean) {
//        if (!allGranted) {
//            toast("获取部分权限成功，但部分权限未正常授予")
//            return
//        }
//        toast("获取录音和日历权限成功")
//    }
//
//    override fun onDenied(permissions: MutableList<String>, doNotAskAgain: Boolean) {
//        if (doNotAskAgain) {
//            toast("被永久拒绝授权，请手动授予录音和日历权限")
//            // 如果是被永久拒绝就跳转到应用权限系统设置页面
//            XXPermissions.startPermissionActivity(context, permissions)
//        } else {
//            toast("获取录音和日历权限失败")
//        }
//    }
//})

//FilePicker.Builder(this)
//                            .setPopUpConfig()
//                            .addPickDocumentFile()
//                            .addImageCapture()
//                            .addVideoCapture()
//                            .addPickMedia()
//                            .build()