package com.tenlionsoft.baselib.utils

import android.content.Context
import android.util.DisplayMetrics
import android.view.WindowManager


class DensityUtils {
    companion object {
        @JvmStatic
        fun dp2px(context: Context, scale: Float): Int {
            return (scale * context.resources.displayMetrics.density + 0.5f).toInt()
        }

        @JvmStatic
        fun px2dp(context: Context, scale: Float): Int {
            return (scale / context.resources.displayMetrics.density + 0.5f).toInt()
        }


        /**
         * sp转换px.
         *
         * @param spValue The value of sp.
         * @return value of px
         */
        @JvmStatic
        fun sp2px(context: Context,spValue: Float): Int {
            val fontScale: Float =context.resources.displayMetrics.scaledDensity
            return (spValue * fontScale + 0.5f).toInt()
        }


        /**
         * px转换sp
         *
         * @param pxValue The value of px.
         * @return value of sp
         */
        @JvmStatic
        fun px2sp(context: Context,pxValue: Float): Int {
            val fontScale: Float = context.resources.displayMetrics.scaledDensity
            return (pxValue / fontScale + 0.5f).toInt()
        }

        @JvmStatic
        fun getDensityDpi(context: Context): Int {
            val displayMetrics = DisplayMetrics()

            (context.getSystemService(Context.WINDOW_SERVICE) as WindowManager).defaultDisplay.getMetrics(
                displayMetrics
            )
            return displayMetrics.densityDpi
        }

        @JvmStatic
        fun getScaledDensity(context: Context): Float {
            val displayMetrics = DisplayMetrics()
            (context.getSystemService(Context.WINDOW_SERVICE) as WindowManager).defaultDisplay.getMetrics(
                displayMetrics
            )
            return displayMetrics.scaledDensity
        }
    }
}